==> haskell-zip-archive-0.3.2.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-zip-archive.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: zip-archive
version: 0.3.2.2
id: zip-archive-0.3.2.2-K0eZwYn7qvVHbDkwj4trrR
key: zip-archive-0.3.2.2-K0eZwYn7qvVHbDkwj4trrR
license: BSD3
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/zip-archive
synopsis: Library for creating and modifying zip archives.
description:
    The zip-archive library provides functions for creating, modifying,
    and extracting files from zip archives.
category: Codec
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    Codec.Archive.Zip
abi: 962b10e2030b7756934734ee67052a74
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/zip-archive-0.3.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/zip-archive-0.3.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/zip-archive-0.3.2.2
hs-libraries: HSzip-archive-0.3.2.2-K0eZwYn7qvVHbDkwj4trrR
depends:
    binary-0.8.5.1 zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM filepath-1.4.1.2
    bytestring-0.10.8.2 array-0.5.2.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus
    digest-0.0.1.2-9121LWkuBzpL6dmPh4HfAu directory-1.3.0.2
    time-1.8.0.2 base-4.10.1.0 pretty-1.1.3.3 containers-0.5.10.2
    unix-2.7.2.2
abi-depends: binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM=fc994ec0331fc01f98e1d968398a1aa2
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus=3a4f708e3a8313990a7ddaa44eed9995
             digest-0.0.1.2-9121LWkuBzpL6dmPh4HfAu=eab7be5e6f9050cf3e35eedfbc3456e9
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-zip-archive/html/zip-archive.haddock
haddock-html: /usr/share/doc/haskell-zip-archive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zip-archive-0.3.2.3-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-zip-archive.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: zip-archive
version: 0.3.2.3
id: zip-archive-0.3.2.3-LgUrGVKZgpI9ReZJW8j79i
key: zip-archive-0.3.2.3-LgUrGVKZgpI9ReZJW8j79i
license: BSD3
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/zip-archive
synopsis: Library for creating and modifying zip archives.
description:
    The zip-archive library provides functions for creating, modifying,
    and extracting files from zip archives.
category: Codec
author: John MacFarlane
exposed: True
indefinite: False
exposed-modules:
    Codec.Archive.Zip
abi: 3c2883150dd2bfc596abfdac7e714230
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/zip-archive-0.3.2.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/zip-archive-0.3.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/zip-archive-0.3.2.3
hs-libraries: HSzip-archive-0.3.2.3-LgUrGVKZgpI9ReZJW8j79i
depends:
    binary-0.8.5.1 zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM filepath-1.4.1.2
    bytestring-0.10.8.2 array-0.5.2.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus
    digest-0.0.1.2-9121LWkuBzpL6dmPh4HfAu directory-1.3.0.2
    time-1.8.0.2 base-4.10.1.0 pretty-1.1.3.3 containers-0.5.10.2
    unix-2.7.2.2
abi-depends: binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             zlib-0.6.1.2-3jYpKaDVsj2d994OadtMM=fc994ec0331fc01f98e1d968398a1aa2
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus=3a4f708e3a8313990a7ddaa44eed9995
             digest-0.0.1.2-9121LWkuBzpL6dmPh4HfAu=eab7be5e6f9050cf3e35eedfbc3456e9
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
haddock-interfaces: /usr/share/doc/haskell-zip-archive/html/zip-archive.haddock
haddock-html: /usr/share/doc/haskell-zip-archive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
